==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/BouncesRemoveListObj.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * BouncesRemoveListObj
 */
@JsonPropertyOrder({ BouncesRemoveListObj.JSON_PROPERTY_EMAIL_ADDRESSES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class BouncesRemoveListObj implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EMAIL_ADDRESSES = "emailAddresses";
    private List<String> emailAddresses = null;

    public BouncesRemoveListObj() {
    }

    public BouncesRemoveListObj emailAddresses(List<String> emailAddresses) {

        this.emailAddresses = emailAddresses;
        return this;
    }

    public BouncesRemoveListObj addemailAddressesItem(String emailAddressesItem) {
        if (this.emailAddresses == null) {
            this.emailAddresses = new ArrayList<>();
        }
        this.emailAddresses.add(emailAddressesItem);
        return this;
    }

    /**
     * A list of email addresses to remove from the email-service bounce list
     *
     * @return emailAddresses
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A list of email addresses to remove from the email-service bounce list")
    @JsonProperty(JSON_PROPERTY_EMAIL_ADDRESSES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getEmailAddresses() {
        return emailAddresses;
    }

    @JsonProperty(JSON_PROPERTY_EMAIL_ADDRESSES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEmailAddresses(List<String> emailAddresses) {
        this.emailAddresses = emailAddresses;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        BouncesRemoveListObj bouncesRemoveListObj = (BouncesRemoveListObj) o;
        return Objects.equals(this.emailAddresses, bouncesRemoveListObj.emailAddresses);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(emailAddresses);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class BouncesRemoveListObj {\n");
        sb.append("    emailAddresses: ").append(toIndentedString(emailAddresses)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/BouncesRemoveListObj.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * BouncesRemoveListObj
 */
@JsonPropertyOrder({ BouncesRemoveListObj.JSON_PROPERTY_EMAIL_ADDRESSES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class BouncesRemoveListObj implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EMAIL_ADDRESSES = "emailAddresses";
    private List<String> emailAddresses = null;

    public BouncesRemoveListObj() {
    }

    public BouncesRemoveListObj emailAddresses(List<String> emailAddresses) {

        this.emailAddresses = emailAddresses;
        return this;
    }

    public BouncesRemoveListObj addemailAddressesItem(String emailAddressesItem) {
        if (this.emailAddresses == null) {
            this.emailAddresses = new ArrayList<>();
        }
        this.emailAddresses.add(emailAddressesItem);
        return this;
    }

    /**
     * A list of email addresses to remove from the email-service bounce list
     *
     * @return emailAddresses
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A list of email addresses to remove from the email-service bounce list")
    @JsonProperty(JSON_PROPERTY_EMAIL_ADDRESSES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getEmailAddresses() {
        return emailAddresses;
    }

    @JsonProperty(JSON_PROPERTY_EMAIL_ADDRESSES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEmailAddresses(List<String> emailAddresses) {
        this.emailAddresses = emailAddresses;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        BouncesRemoveListObj bouncesRemoveListObj = (BouncesRemoveListObj) o;
        return Objects.equals(this.emailAddresses, bouncesRemoveListObj.emailAddresses);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(emailAddresses);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class BouncesRemoveListObj {\n");
        sb.append("    emailAddresses: ").append(toIndentedString(emailAddresses)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
